==> ui-list-10.15.2.tgz: package/lib/List/ListItem/__new-tests__/ListItem.test.js <==
"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault").default;
var _react = _interopRequireDefault(require("react"));
require("@testing-library/jest-dom");
var _react2 = require("@testing-library/react");
var _vitest = require("vitest");
var _index = require("../index");
var _ListItem;
/*
 * The MIT License (MIT)
 *
 * Copyright (c) 2015 - present Instructure, Inc.
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */
describe('<ListItem />', () => {
  it('should render children', async () => {
    (0, _react2.render)(_ListItem || (_ListItem = /*#__PURE__*/_react.default.createElement(_index.ListItem, null, "hello")));
    const listItem = _react2.screen.getByRole('listitem');
    expect(listItem).toHaveTextContent('hello');
  });
  it('should call elementRef', async () => {
    const elementRef = _vitest.vi.fn();
    (0, _react2.render)(/*#__PURE__*/_react.default.createElement(_index.ListItem, {
      elementRef: elementRef
    }, "List item"));
    const listItem = _react2.screen.getByRole('listitem');
    expect(elementRef).toHaveBeenCalledWith(listItem);
  });
});

==> ui-list-10.19.1.tgz: package/lib/List/ListItem/__new-tests__/ListItem.test.js <==
"use strict";

require("@testing-library/jest-dom");
var _react = require("@testing-library/react");
var _vitest = require("vitest");
var _index = require("../index");
var _jsxRuntime = require("@emotion/react/jsx-runtime");
var _ListItem;
/*
 * The MIT License (MIT)
 *
 * Copyright (c) 2015 - present Instructure, Inc.
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */
describe('<ListItem />', () => {
  it('should render children', async () => {
    (0, _react.render)(_ListItem || (_ListItem = (0, _jsxRuntime.jsx)(_index.ListItem, {
      children: "hello"
    })));
    const listItem = _react.screen.getByRole('listitem');
    expect(listItem).toHaveTextContent('hello');
  });
  it('should call elementRef', async () => {
    const elementRef = _vitest.vi.fn();
    (0, _react.render)((0, _jsxRuntime.jsx)(_index.ListItem, {
      elementRef: elementRef,
      children: "List item"
    }));
    const listItem = _react.screen.getByRole('listitem');
    expect(elementRef).toHaveBeenCalledWith(listItem);
  });
});
